import pygame

def text_draw(win, text_list, rect, color ,font,  input_spacer_counter = None, input_active = None, binde_seite = "mitte"):

    zeilen = len(text_list)
    anfangs_y = rect.y + rect.height/2

    # wenn binde seite nicht mitte dann puffer
    abstand_zu_seite = 5

    for index, zeile in enumerate(text_list): 
            
        t_input = font.render(zeile, True, (color))
        text_height_platz = rect.height / zeilen  
        eine_zeile_anteil = (zeilen - 1)/2
        mitte_verschiebung = t_input.get_height()/2
        index_abhangige_verschiebung = (index - eine_zeile_anteil) * text_height_platz 
        y = anfangs_y - mitte_verschiebung + index_abhangige_verschiebung
        if binde_seite == "mitte":
            x = rect.x + rect.width//2 - t_input.get_width()//2 
        elif binde_seite == "links":
            x = rect.x + abstand_zu_seite
        elif binde_seite == "rechts":
            x = rect.x  + rect.width - t_input.get_width() - abstand_zu_seite

        win.blit(t_input, (x, y))

    if input_active and input_spacer_counter % 30 >= 15:
        t_spacer = font.render("|", True, (color))

        if binde_seite == "mitte":
            spacer_x = x + t_input.get_width()
        elif binde_seite == "links":
            spacer_x = x + t_input.get_width() 
        elif binde_seite == "rechts":
            spacer_x = rect.x + rect.width - abstand_zu_seite*1.5
            
        win.blit(t_spacer, (spacer_x, y))



import pygame
from pygame import gfxdraw

def opacity_line(dimentions,color, op):
    """returns line surface with opacity 

    Args:
        dimentions (tuple): (width , height)
        color (tuble): (c1, c2, c3)
        op (float): number from 0 to 1 (percent of opacity)

    Returns:
        [surface]: surface to blit line
    """
    width, height = dimentions
    s = pygame.Surface((width, height), pygame.SRCALPHA)
    s.fill((color[0], color[1], color[2], int(op * 255)))

    return s

def opacity_rect(dimentions, color, op, lines_to_draw = (True, True, True, True), index = 0, breite = -1):
    """retruns multible surfaces with relativ drawing cords which together are the rectangle

    Args:
        dimentions (tuple): (width , height)
        color (tuble): (c1, c2, c3)
        op (float): number from 0 to 1 (percent of opacity)
        lines_to_draw (tuple with ints in): left, right, top, bottem
        index (int) : if every round is more relocated
        breite (int, optional): width of single line. Defaults to -1.

    Returns:
        [(rel_x,rel_y), surface]: list of relative_draw_cords, surface
    """
    width, height = dimentions

    if breite == -1:
        gesamt_surface = pygame.Surface((width, height), pygame.SRCALPHA)
        gesamt_surface.fill((color[0], color[1], color[2], int(op * 255)))
    else:
        gesamt_surface = []
        vertical = opacity_line((breite, height), color, op)
        horizontal = opacity_line((width - 2* breite, breite), color, op)
        if lines_to_draw[0]:
            gesamt_surface.append(((0 + index,0), vertical))
        if lines_to_draw[1]:
            gesamt_surface.append(((width - breite - index,0), vertical))
        if lines_to_draw[2]:
            gesamt_surface.append(((breite, 0 + index), horizontal))
        if lines_to_draw[3]:
            gesamt_surface.append(((breite, height- breite - index), horizontal,))

    return gesamt_surface

def draw_aacircle(win, color, cords, radius, filled = True):
    x,y = cords
    x, y, radius = int(x), int(y), int(radius)
    gfxdraw.aacircle(win, x, y, radius, color)
    if filled:
        gfxdraw.filled_circle(win, x, y, radius, color)

def draw_aatriangle(win, color, cords1 , cords2, cords3, filled = True):
    x1,y1 = cords1
    x2,y2 = cords2
    x3,y3 = cords3
    x1, y1, x2, y2, x3,y3 = int(x1), int(y1), int(x2), int(y2), int(x3),int(y3)
    
    pygame.gfxdraw.filled_trigon(win, x1, y1, x2, y2, x3, y3, color)
    if filled:
        pygame.gfxdraw.aatrigon(win, x1, y1, x2, y2, x3, y3, color)

    
# pygame.gfxdraw.aafilled_circle(WIN, 100, 100, 50, (255,0,0))


# x = opacity_rect((100,100), (255,255,0), 0.5, 5) 
# print(x)   


import random
import pygame
import math
import sys


def getmousecollision(maus, buttonx, buttony, width, height, verschiebung=0):
    if maus[0] >= buttonx and maus[0] <= buttonx + width and maus[1] >= buttony and maus[1] <= buttony + height or maus[0] >= buttonx + verschiebung and maus[0] <= buttonx + width + verschiebung and maus[1] >= buttony + verschiebung and maus[1] <= buttony + height + verschiebung:
        return True
    else:
        return False


def graph_zeichnen(databekommen, soll_wert=-1):
    pygame.init()
    pygame.font.init()

    scrwidth = 1000
    scrheight = 600

    pygame.init()
    win = pygame.display.set_mode((scrwidth, scrheight))
    pygame.display.set_caption("Graph")
    font = pygame.font.SysFont("comicsans", 30)

    clock = pygame.time.Clock()

    data = []
    großter = 0
    kleinster = 0
    durchschnitt = 0
    median = 0
    sortierte_liste = []
    ausgewahlt = False

    for i, d in enumerate(databekommen):
        data.append([i, d[0], d[1]])

    datalange = len(data)

    # median berechnen

    def takeSecond(elem):
        return elem[2]

    großtere_zahl = round(max(data, key=takeSecond)[2], 2)
    großter = großtere_zahl
    if großter < soll_wert:
        großter = soll_wert
    kleinster = round(min(data, key=takeSecond)[2], 2)

    sortierte_liste = data.copy()
    sortierte_liste.sort(key=takeSecond)
    median = round(sortierte_liste[int(datalange/2)][2], 2)

    # durchschnitt berechnen

    gesamt = 0
    for i in data:
        gesamt += i[2]
    durchschnitt = round(gesamt/datalange, 2)

    radius = 4

    x = font.render(str(round(großter, 1)), False, (255, 0, 0))

    abstand_zum_rand = 90
    if x.get_width() + 35 >= abstand_zum_rand:
        abstand_zum_rand = x.get_width() + 35

    abstand_linien = 10
    linien_breite_kurz = 2
    linien_breite_lang = 2
    langern_unterschied = 5
    zahlen_abstand_vom_stirch = 8
    x_und_y_gleichlang = True
    anzahl_x = 10
    anzahl_y = 10
    lange = 20
    abstand_durch_medi_linie = 40

    maximalskalierung = 10
    richtskalierung = 8

    if soll_wert > 0:
        y_soll = int(scrheight - abstand_zum_rand - ((scrheight-abstand_zum_rand-abstand_linien * 2))
                     * soll_wert/großter)

    y_durch = int(scrheight - abstand_zum_rand - ((scrheight-abstand_zum_rand-abstand_linien * 2))
                  * durchschnitt/großter)
    y_medi = int(scrheight - abstand_zum_rand - ((scrheight-abstand_zum_rand-abstand_linien * 2))
                 * median/großter)

    def draw():
        win.fill((0, 0, 0))

        if int(datalange/richtskalierung) > 1:
            skalierungen = richtskalierung+1
        else:
            skalierungen = datalange

        zahler = math.ceil((x.get_width() * (skalierungen + 1)
                            )/(scrwidth - abstand_zum_rand)) - 1

        pygame.draw.line(win, (255, 255, 255), (abstand_zum_rand, scrheight-abstand_zum_rand),
                         (scrwidth-(abstand_linien), scrheight-abstand_zum_rand), 2)
        pygame.draw.line(win, (255, 255, 255), (abstand_zum_rand, scrheight-abstand_zum_rand),
                         (abstand_zum_rand, abstand_linien), 2)

        for content in data:

            # kord x und y
            kordx = [int(abstand_zum_rand + (scrwidth-abstand_zum_rand-abstand_linien * 2)
                         * content[0]/data[-1][0]), scrheight - abstand_zum_rand]

            kordy = [abstand_zum_rand, int(
                scrheight - abstand_zum_rand - ((scrheight-abstand_zum_rand-abstand_linien * 2)) * (content[0]/data[-1][0]))]

            # Circle Position
            circ_pos = [int(abstand_zum_rand + (scrwidth-abstand_zum_rand-abstand_linien * 2)
                            * content[0]/data[-1][0]), int(scrheight - abstand_zum_rand - ((scrheight-abstand_zum_rand-abstand_linien * 2))
                                                           * content[2]/großter)]

            # Skalierung

            skzeichnen = False

            if datalange >= maximalskalierung:
                if content[0] % int(datalange/richtskalierung) == 0:
                    skzeichnen = True
            else:
                skzeichnen = True

            zahlanzeigen = False

            if skzeichnen:
                pygame.draw.line(
                    win, (0, 255, 0), (kordy[0] - 5, kordy[1]), (kordy[0] + 5, kordy[1]), linien_breite_kurz)

                if zahler == math.ceil((x.get_width() * (skalierungen + 1))/(scrwidth - abstand_zum_rand)) - 1:
                    zahlenx = font.render(
                        str(round(content[1], 2)), False, (255, 0, 0))
                    win.blit(
                        zahlenx, (int(kordx[0] - zahlenx.get_width()/2), kordx[1] + zahlen_abstand_vom_stirch))

                    if x.get_width() * (skalierungen+1) > scrwidth - abstand_zum_rand:
                        zahler = 0
                else:
                    zahler += 1

                anzeigezahly = content[0] * (großter/data[-1][0])

                if str(anzeigezahly)[-1] == "0":
                    anzeigezahly = str(int(anzeigezahly))
                else:
                    anzeigezahly = str(round(anzeigezahly, 1))

                zahleny = font.render(
                    anzeigezahly, False, (0, 255, 0))
                win.blit(
                    zahleny, (int(kordy[0] - zahleny.get_width() - zahlen_abstand_vom_stirch), int(kordy[1] - zahleny.get_height()/2 + zahlen_abstand_vom_stirch/3)))

                pygame.draw.line(
                    win, (255, 0, 0), (kordx[0], kordx[1] - 5), (kordx[0], kordx[1] + 5), linien_breite_kurz)

            # Kreise
            pygame.draw.circle(
                win, (0, 0, 255), (circ_pos[0], circ_pos[1]), radius)

        pygame.draw.rect(win, (255, 255, 255), (20, int(
            scrheight-abstand_zum_rand/2 - lange + 10), 40, 40))

        if ausgewahlt:
            pygame.draw.rect(win, (100, 200, 100), (25, int(
                scrheight-abstand_zum_rand/2 - lange + 10 + 5), 30, 30))
            gros = font.render(
                "H:"+str(großtere_zahl), False, (255, 255, 255))
            klein = font.render(
                "T:"+str(kleinster), False, (255, 255, 255))
            medi = font.render(
                "M:"+str(median), False, (240, 170, 0))
            durch = font.render(
                "D:"+str(durchschnitt), False, (210, 4, 70))
            win.blit(
                gros, (300, int(scrheight-(abstand_zum_rand * 2/3) - gros.get_height()/2) + 10))
            win.blit(
                klein, (300, int(scrheight-(abstand_zum_rand * 1/3) - gros.get_height()/2) + 10))
            win.blit(
                medi, (100, int(scrheight-(abstand_zum_rand * 2/3) - gros.get_height()/2) + 10))
            win.blit(
                durch, (100, int(scrheight-(abstand_zum_rand * 1/3) - gros.get_height()/2) + 10))

            pygame.draw.line(win, (210, 4, 70), (abstand_zum_rand,
                                                 y_durch), (scrwidth-abstand_linien - abstand_durch_medi_linie, y_durch), 2)
            pygame.draw.line(win, (240, 170, 0), (abstand_zum_rand,
                                                  y_medi), (scrwidth-abstand_linien - abstand_durch_medi_linie, y_medi), 2)

            medi_linien_letter = font.render(
                "M", False, (240, 170, 0))
            durch_linien_letter = font.render(
                "D", False, (210, 4, 70))
            win.blit(
                medi_linien_letter, (int(scrwidth - abstand_durch_medi_linie - 5), int(y_medi - medi_linien_letter.get_height()/2) + 2))
            win.blit(
                durch_linien_letter, (int(scrwidth - abstand_durch_medi_linie - 5), int(y_durch - durch_linien_letter.get_height()/2 + 2)))

        else:
            pygame.draw.rect(win, (200, 100, 100), (25, int(
                scrheight-abstand_zum_rand/2 - lange + 10 + 5), 30, 30))

        if soll_wert > 0:
            pygame.draw.line(win, (5, 210, 190), (abstand_zum_rand,
                                                  y_soll), (scrwidth-abstand_linien, y_soll), 2)

    run = True

    while run:
        clock.tick(20)
        maus = pygame.mouse.get_pos()

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False

            if getmousecollision(
                    maus, 20, int(scrheight-abstand_zum_rand/2 - lange + 10), 40, 40) and event.type == pygame.MOUSEBUTTONDOWN:
                ausgewahlt = not ausgewahlt

        keys = pygame.key.get_pressed()

        draw()

        pygame.display.update()

    pygame.quit()


def create_data():
    infos = []
    for i in range(0, int(math.pi * 100), 1):
        x = (i)
        # y = math.sin(i/50)
        # y = 2.72**i
        y = int((i**2 - (i**2.5) * 0.1) + 10)
        infos.append([x, y])

    return(infos)


# graph_zeichnen(create_data())




import pygame
vec = pygame.math.Vector2

class Camera:
    def __init__(self, borders, SCRWIDTH, SCRHEIGHT):
        self.SCRWIDTH, self.SCRHEIGHT= SCRWIDTH, SCRHEIGHT
        self.HW, self.HH= self.SCRWIDTH//2, self.SCRHEIGHT//2
        self.offset = vec(0,0)
        self.scale = 1
        self.leftb, self.topb, self.rightb, self.bottemb = borders
        self.veranderungs_schwelle = 0

    def scroll(self, pl):
        """with new_player cords given it updates to offset 

        Args:
            pl (obj.x, obj.y): player_x, player_y
        """             

        self.player = vec(pl.x, pl.y) 

        # als basis dient die world Koordinate des Players, da der offset immer von oben links ausgeht wird die halbe screenbreite 
        # mal 1/scale (relative screenbreite) abgezogen
        self.offset.x = self.player.x - (1/self.scale) * self.HW

        # wenn linke border (0) groser ist als der offset (lniks oben gemessen) ist, so ist die border (0) oder neue offset
        self.offset.x = max(self.offset.x, self.leftb) 

        # selbes spiel nur muss von der rechten border noch die relative screenbreite abgezogen werden, damit sie auf der hohe des
        # offsets ist (auf der linken seite des fensters)
        self.offset.x = min(self.offset.x, self.rightb  - self.SCRWIDTH * (1/self.scale))
        
        self.offset.y = self.player.y  - (1/self.scale) * self.HH
        self.offset.y = max(self.offset.y, self.topb)
        self.offset.y = min(self.offset.y, self.bottemb - self.SCRHEIGHT* (1/self.scale))


    def world_to_screen(self, wx, wy):
        """converts world cords to relative screen cords you can actually draw

        Args:
            wx (numb): world_x
            wy (numb): world y

        Returns:
            tuple: (screen_x, screen_y)
        """
        sx = (wx - self.offset.x) * self.scale
        sy = (wy - self.offset.y) * self.scale
        return sx, sy

    def screen_to_world(self, sx, sy):
        """converts relative screen cords to global ones
        example mouse cords to global

        Args:
            sx (numb): screen_x
            sy (numb): screen y

        Returns:
            tuple: (world_x, world_y)
        """
        wx = (sx/self.scale) + self.offset.x 
        wy = (sy/self.scale) + self.offset.y 
        return wx, wy
    
    def get_zoom_lange(self, lange):
        """returns length of obj when scale is applied

        Args:
            lange (numb): lange

        Returns:
            numb: new_lange
        """
        return lange * self.scale
    
    def get_view_dims_world(self):
        """returns relative screen dimentions with scale applied

        Returns:
            tuple: (length, height)
        """
        sicht_x = self.SCRWIDTH * (1/self.scale)
        sicht_y = self.SCRHEIGHT * (1/self.scale)
        return sicht_x, sicht_y    

    def get_draw_cords(self, x, y, *langen):
        """retruns cords to draw on the screen
        (basically only converts world to screen Cords)

        Args:
            x (numb): world_x
            y (numb): world_y
            langen (numb, numb...) : langen to covert 

        Returns:
            int, int: draw_x, draw_y
            opitonal langen
        """

        draw_x, draw_y = self.world_to_screen(x, y)

        zoom_langen = []
        for lange in langen:
            zoom_langen.append(int(self.get_zoom_lange(lange)))

        if zoom_langen:
            return int(draw_x), int(draw_y), zoom_langen
        else:
            return int(draw_x), int(draw_y)




from .constants import HW,HH, SCRWIDTH, SCRHEIGHT

import pygame
vec = pygame.math.Vector2

class Camera:
    def __init__(self, borders):
        self.offset = vec(0,0)
        self.zoom_offset = vec(0,0)
        self.scale = 1
        self.leftb, self.topb, self.rightb, self.bottemb = borders

    def scroll(self, pl):
        self.player = vec(pl["x"], pl["y"]) 
 
        self.offset.x += int(self.player.x - self.offset.x - HW)
        self.offset.y += int(self.player.y - self.offset.y - HH)

        zoom_ausgeleichx = (HW * (1/self.scale)) - HW
        zoom_ausgeleichy = (HH * (1/self.scale)) - HH

        self.offset.x = max(self.offset.x, self.leftb + zoom_ausgeleichx) 
        self.offset.x = min(self.offset.x, self.rightb - SCRWIDTH - zoom_ausgeleichx)
        self.offset.y = max(self.offset.y, self.topb + zoom_ausgeleichy)
        self.offset.y = min(self.offset.y, self.bottemb - SCRHEIGHT - zoom_ausgeleichy)


    def world_to_screen(self, wx, wy):
        sx = wx - self.offset.x
        sy = wy - self.offset.y
        return sx, sy

    def screen_to_world(self, sx, sy):
        wx = (sx) + self.offset.x 
        wy = (sy) + self.offset.y 
        return wx, wy
    
    def get_zoom_lange(self, lange):
        return lange * self.scale

    def get_zoom_borders(self):
        # berechner neuen border der welt mit kamera zoom eingerechner (stoßen an anderen koordinaten an je nach zoom)
        zoom_border_cords = HW * (1/self.scale),  self.rightb - HW * (1/self.scale), HH * (1/self.scale), self.bottemb - HH * (1/self.scale)
        return zoom_border_cords

    def get_draw_cords(self, x, y, *langen):

            # für bezugspunkt angepasste borders im fall das figur an wand und kamera sttationär ist 
        # dann soll der stattionäre punkt der bezugspunkte sein 
        zoomb_left, zoomb_right, zoomb_top, zoomb_bottem = self.get_zoom_borders()

        # als standart werte erstmal spieler position
        zoom_bezug_x, zoom_bezug_y = self.player.x, self.player.y
        zoom_bezug_x = max(zoom_bezug_x, zoomb_left)
        zoom_bezug_x = min(zoom_bezug_x, zoomb_right)
        zoom_bezug_y = max(zoom_bezug_y, zoomb_top)
        zoom_bezug_y = min(zoom_bezug_y, zoomb_bottem)

        # Differenz objekt positon und bezugpunkt
        dx, dy =  x - zoom_bezug_x,  y - zoom_bezug_y
        # zoomkonstante nur auf differenz der zwischen pnkt und bezugspunkt und nicht absolte werte angewand
        dx *= self.scale
        dy *= self.scale
        draw_x = dx + zoom_bezug_x
        draw_y = dy + zoom_bezug_y

        draw_x, draw_y = self.world_to_screen(draw_x, draw_y)

        zoom_langen = []
        for lange in langen:
            zoom_langen.append(int(self.get_zoom_lange(lange)))

        if zoom_langen:
            return int(draw_x), int(draw_y), zoom_langen
        else:
            return int(draw_x), int(draw_y)
            
      
    def zoom(self, delta):

        mid_davor = vec(self.world_to_screen(self.player.x, self.player.y))

        self.scale *= delta

        player_screen =  vec(self.world_to_screen(self.player.x, self.player.y))
        

        # if HW - player_screen.x < 10:
        #     self.zoom_offset.x -= (HW - player_screen.x) 
        #     self.zoom_offset.y -= (HH - player_screen.y) 
        # else:
        #     print("self.zoom_offset nicht verandert")





from draw_assistance import draw_aacircle
import pygame
import os
import sys
from pygame import gfxdraw


SCRWIDTH = 600
SCRHEIGHT = 600

HW = SCRWIDTH //2
HH = SCRHEIGHT //2

WHITE = (255, 255, 255)
BLACK = (0, 0, 0)
GREY = (100, 100, 100)
RED = (255, 30, 30)
GREEN = (30, 255, 30)
BLUE = (30, 30, 255)

FPS = 60


pygame.init()
WIN = pygame.display.set_mode((SCRWIDTH, SCRHEIGHT))
pygame.display.set_caption("Space Game")
FONT = pygame.font.SysFont("comicsans", 30)
directory_of_file = os.path.normpath(sys.argv[0] + os.sep + os.pardir)


CLOCK = pygame.time.Clock()

def draw():
    WIN.fill((0, 0, 0))
    radius = 70
    color = RED
    x = 150  
    y = 300
    # draw_aacircle(WIN, RED, (150, 150) , radius)
    pygame.draw.circle(WIN, RED, (300, 150), radius)    
    # pygame.gfxdraw.aacircle(WIN, 450, 150, radius, RED)
    # for i in range(20):      
    #     gfxdraw.aacircle(WIN, x, y, radius- i , color)

    # gfxdraw.aacircle(WIN, x, y, radius-1, color)
    # gfxdraw.aacircle(WIN, x, y, radius-2, color)
    gfxdraw.filled_circle(WIN, x, y, radius, color)


 
input_font = pygame.font.SysFont("comicsans",30)

def main():
    run = True

    while run:
        CLOCK.tick(FPS)
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False

        keys = pygame.key.get_pressed()

        draw()

        pygame.display.update()


main()
pygame.quit()



import pygame
import math

if __name__ == '__main__':
    from draw_text_list import text_draw
else:
    from .draw_text_list import text_draw
  
class InputBox:
    def __init__(self,  x, y, width, height, input_color_active =(235,235,235) , input_color_passive = (130, 130, 130), 
                        standard_input_text = "", input_max_len = None, mit_spacer = True, mit_zeilen_umbruch = False,
                        input_anfangs_active = False, umrandung = "rect", input_max_len_automatic = False,
                        input_font_size = None, input_max_len_font_size = None, max_len_info_anzeigen = True, 
                        anfangs_anzeige_text = "", vergroserungs_richtung = "beide", font_size_height_rel = 0.8,
                        zeilen_abstand_rel = 1, binde_seite = "mitte", mit_user_next_line = True, input_max_len_rendered = None, 
                        font_path = None):

        """umrandung: "rect", "line"
            vergroserungs_richtung: "beide", "oben", "unten"
            binde_seite: "mitte", "rechts", "links"
        """  

        self.width = width
        self.height = height
        self.anfangs_height = self.height
        x += self.width/2
        y += self.height/2
        self.anfangs_y = y
        self.anfangs_x = x
        self.input_color_active = input_color_active
        self.input_color_passive = input_color_passive
        self.input_color = self.input_color_passive
        
        self.input_max_len = input_max_len
        self.mit_spacer = mit_spacer
        self.mit_zeilen_umbruch = mit_zeilen_umbruch
        self.input_active = input_anfangs_active
        self.umrandung = umrandung
        self.max_len_info_anzeigen = max_len_info_anzeigen
        self.vergroserungs_richtung = vergroserungs_richtung
        self.font_size_height_rel = font_size_height_rel
        self.zeilen_abstand_rel = zeilen_abstand_rel
        self.binde_seite = binde_seite
        self.mit_user_next_line = mit_user_next_line
        self.input_max_len_rendered = input_max_len_rendered
        self.font_path = font_path

        self.input_rect = pygame.Rect(x - self.width /2, y - self.height/2 , self.width, self.height)

        self.input_spacer_counter = 0
        self.backspace_counter = 0

        self.backspace_active = False
        self.backspace_active_counter = 0
        self.backspace_fast = False
        self.backspace_interval_anfang = 7
        self.backspace_interval = self.backspace_interval_anfang
        self.backspace_interval_fast = 2

        self.input_text_ist_max_len = False
        self.zeilen_umbruch_rel = 0.9

        self.input_font_size = input_font_size
        self.input_max_len_font_size = input_max_len_font_size

        self.schonmal_gezeichnet = False

        self.set_input_font_sizes()

        self.input_max_len_automatic = input_max_len_automatic

        self.anfangs_anzeige_text_list = self.get_str_or_list(anfangs_anzeige_text)
        self.input_text_list = self.get_str_or_list(standard_input_text)

        if self.anfangs_anzeige_text_list != [""]:
            self.input_text_list = self.anfangs_anzeige_text_list 

        self.input_text_index = len(self.input_text_list) - 1 
         
        for _ in range(1, len(self.input_text_list)):  
            self.rect_verschiebung_add_zeile()

    def get_str_or_list(self, obj):
        if type(obj) == str:
            new_obj = [obj]
        else:
            new_obj = obj
    
        return new_obj

    def get_input_text(self):
        return self.input_text_list
    
    def get_input_text_gesamt_len(self):
        """returns lenght of whole text

        Returns:
            int: text len
        """

        lange = 0
        for zeile in self.input_text_list:
            lange += len(zeile)

        return lange


    def set_input_font_sizes(self):
        """sets font sizes depending on prefrence (input_font_size, input_max_len_font_size) or
        sets it to be 80 percent of height
        """

        if self.font_path:
            font_name = self.font_path

            if self.input_font_size:
                self.input_font = pygame.font.Font(font_name, self.input_font_size)
            else:
                input_font_height = int(self.height * self.font_size_height_rel)
                self.input_font = pygame.font.Font(font_name, input_font_height)
    
            if self.input_max_len_font_size:
                self.input_max_len_font = pygame.font.Font(font_name, self.input_max_len_font_size)
            else:
                input_max_font_height = int(input_font_height * self.font_size_height_rel)
                self.input_max_len_font = pygame.font.Font(font_name, input_max_font_height)
        else:
            font_name = "comicsans"

            if self.input_font_size:
                self.input_font = pygame.font.SysFont(font_name, self.input_font_size)
            else:
                input_font_height = int(self.height * self.font_size_height_rel)
                self.input_font = pygame.font.SysFont(font_name, input_font_height)

            if self.input_max_len_font_size:
                self.input_max_len_font = pygame.font.SysFont(font_name, self.input_max_len_font_size)
            else:
                input_max_font_height = int(input_font_height * self.font_size_height_rel)
                self.input_max_len_font = pygame.font.SysFont(font_name, input_max_font_height)

        self.input_font_test_width, self.input_font_test_height = self.input_font.size("A")
            
    def remove_one_character(self):

        """is called when backspace is pressed and removes one character or eliminates empty line
        """
        
        if len(self.input_text_list[self.input_text_index]) == 0 and self.input_text_index != 0:
            # line is removed
            self.input_text_list.pop(self.input_text_index)
            self.rect_verschiebung_remove_zeile()
            self.input_text_index -= 1
            self.backspace_counter = 0
        else:
            # single character is removed
            self.input_text_list[self.input_text_index] = self.input_text_list[self.input_text_index][:-1]
            self.backspace_counter = 0
        self.backspace_active_counter += 1

    def update(self):

        """ removes character/empty line when backspace is continuesly pressed
            adds new line (if possible) if current text runs over its boundaries
        """

        self.backspace_counter += 1

        if self.mit_spacer:
            self.input_spacer_counter += 1
        
        # if backspace button is still pressed and counter is over the maximum interval one character is removed and 
        # after some time the backspace interval is reduced
        if self.backspace_active and self.backspace_counter >= self.backspace_interval:
            self.remove_one_character()

            if self.backspace_active_counter > 3:
                self.backspace_interval = self.backspace_interval_fast
            else:
                self.backspace_interval = self.backspace_interval_anfang
  
        # if mit_zeilen_umbruch is on and the line is larger than it's bounardies new line might be created
        # rect and text position is changed in order to fit with the added line
        if self.mit_zeilen_umbruch and self.schonmal_gezeichnet:
            self.t_problem_zeile = self.input_font.render(self.input_text_list[self.input_text_index], True, (self.input_color_active))
            if self.t_problem_zeile.get_width() > self.width * self.zeilen_umbruch_rel:
                
                # problem_index festgelegt und in aktuellen index des textes erhoht
                problem_index = self.input_text_index
                self.input_text_index += 1

                while self.t_problem_zeile.get_width() > self.width * self.zeilen_umbruch_rel:

                    # wenn es in zeile getrennte worter gibt dann wird gesamtes wort als letzter character geonommen
                    if len(self.input_text_list[problem_index].split(" ")) > 1:
                        last_characters = self.input_text_list[problem_index].split(" ")[-1]
                        split_index = len(self.input_text_list[problem_index]) - 1 - len(last_characters)
                    else:
                        last_characters = self.input_text_list[problem_index][-1]
                        split_index = -1

                    

                    # alte (problem) zeile wird um last characters verkürzt
                    self.input_text_list[problem_index] =  self.input_text_list[problem_index][:split_index]
                    problem_zeile = self.input_text_list[problem_index]

                    # wenn eine weitere zeile existiert (sollte eigentlich nicht) wird dahin zugefugt sonst wird neue zeile erschaffen
                    if len(self.input_text_list) - 1 == problem_index:
                        self.input_text_list.append(last_characters)
                    else:
                        self.input_text_list[self.input_text_index] = last_characters + self.input_text_list[self.input_text_index]

                    self.t_problem_zeile = self.input_font.render(problem_zeile, True, (self.input_color_active))

                self.rect_verschiebung_add_zeile()
        
                
    def rect_verschiebung_add_zeile(self):
        """changes rect position because of new line
        """
        height_faktor = self.zeilen_abstand_rel

        # anpassungen fur die erweiterungsrichtungen
        if self.vergroserungs_richtung == "beide":
            y_faktor = 1 * height_faktor
        elif self.vergroserungs_richtung == "oben":
            y_faktor = 2 * height_faktor
        elif self.vergroserungs_richtung == "unten":
            y_faktor = 0
        

        self.input_rect.y -= (self.anfangs_height * y_faktor)/2
        self.input_rect.height += self.anfangs_height * height_faktor

    def rect_verschiebung_remove_zeile(self):
        """changes rect position because of removed line
        """
        height_faktor = self.zeilen_abstand_rel

        if self.vergroserungs_richtung == "beide":
            y_faktor = 1 * height_faktor
        elif self.vergroserungs_richtung == "oben":
            y_faktor = 2 * height_faktor
        elif self.vergroserungs_richtung == "unten":
            y_faktor = 0


        self.input_rect.y += (self.anfangs_height * y_faktor)/2
        self.input_rect.height -= self.anfangs_height * height_faktor
        
    def reset_box(self):

        for _ in range(1, len(self.input_text_list)):  
            self.rect_verschiebung_remove_zeile()
        
        self.input_text_list = [""]
        self.input_text_index = 0


    def event_check(self, event):
        """reacts to all keypresses and if possible adds it to line/new line 
            removes when backspace 
            creates new line when enter

            also reaction on activation of field by mouse event

        Args:
            event ([type]): [description]
        """


        # activation of field based on mouse activity
        if event.type == pygame.MOUSEBUTTONDOWN and event.button == 1:

            # fokus nun auf feld
            if self.input_rect.collidepoint(event.pos):
                self.input_active = True
                self.input_color = self.input_color_active
                
                # wenn in aktueller input_text_list items existieren dann zu letztem item sonst immer zu 0
                if len(self.input_text_list) == 0 or self.input_text_list == self.anfangs_anzeige_text_list:
                    self.input_text_index = 0
                else:
                    self.input_text_index = len(self.input_text_list) - 1
                    
                # wenn erst anfangs_anzeige text in feld stand dann verschwindet dieser auf fokus und feld passt sich an
                if self.anfangs_anzeige_text_list and self.input_text_list == self.anfangs_anzeige_text_list:
                    for _ in range(1, len(self.input_text_list)):  
                        self.rect_verschiebung_remove_zeile()
                    self.input_text_list = [""]
            
            # woanders hin geklickt (fokus nicht auf feld)
            else:
                self.input_active = False
                self.input_color = self.input_color_passive
                # wenn es anfangs anzeige text gibt und das feld leer ist so wird wieder dieser text angezeigt wenn es fokus verliert
                if self.anfangs_anzeige_text_list and self.input_text_list == [""]:
                    self.input_text_list = self.anfangs_anzeige_text_list
                    self.index = len(self.input_text_list) -1 
                    for _ in range(1, len(self.input_text_list)):  
                        self.rect_verschiebung_add_zeile()

        if event.type == pygame.KEYDOWN:
            if self.input_active:
                if event.key == pygame.K_BACKSPACE:
                    # if not self.backspace_active the event is registert for the first time in a row so removes character immediately
                    if not self.backspace_active:
                        self.remove_one_character()
                        self.backspace_counter = 0

                    self.backspace_active = True

                elif event.key == pygame.K_RETURN:
                    if self.mit_user_next_line:
                        if not self.input_text_ist_max_len:
                            self.input_text_list.append("")
                            self.input_text_index += 1  
                            self.rect_verschiebung_add_zeile()

                elif event.key == pygame.K_ESCAPE:
                    self.reset_box()

                # if normal character is pressed
                else:
                    add_character = True
                    # character isn't added to text under following conditions

                    # 1. max input lenght is determined automatically and adding a large character would be over the bounaries
                    if self.input_max_len_automatic and not self.input_max_len:
                        if self.t_current_row.get_width() + self.input_font_test_width > self.width * self.zeilen_umbruch_rel:
                            add_character = False
                    
                    # 2. the initially given character limit is reached
                    if self.input_max_len_rendered:
                        text_width = self.input_font.render(self.input_text_list[self.input_text_index], True, (0,0,0)).get_width()
                        if text_width + self.input_font_test_width > self.input_max_len_rendered:
                            add_character = False

                    if self.input_max_len:
                        if self.get_input_text_gesamt_len() > self.input_max_len:
                            add_character = False
                            
                    if add_character:
                        self.input_text_ist_max_len = False
                        self.input_text_list[self.input_text_index] += event.unicode
                    else:
                        # if no character is added something went wrong and so the input_text must be at it's maximum
                        self.input_text_ist_max_len = True 
                    

        if event.type == pygame.KEYUP:
            if event.key == pygame.K_BACKSPACE:
                self.backspace_active = False
                self.backspace_active_counter = 0
                

        
    def draw(self, win):

        self.schonmal_gezeichnet = True

        if self.umrandung == "rect":
            pygame.draw.rect(win, self.input_color, self.input_rect, 2)  
        elif self.umrandung == "line":
            pygame.draw.line(win, self.input_color, (self.input_rect.x, self.input_rect.y + self.input_rect.height), (self.input_rect.x + self.width, self.input_rect.y + self.input_rect.height))

        color =  self.input_color_active
        # wird Grau (passiv) wenn input nicht aktiv und der angezeigte text der anfangs anzeige text ist
        if not self.input_active and self.input_text_list == self.anfangs_anzeige_text_list:
            color = self.input_color_passive
        
        text_draw(win, self.input_text_list, self.input_rect, color, self.input_font , 
                    input_spacer_counter= self.input_spacer_counter, input_active= self.input_active, 
                    binde_seite = self.binde_seite)

        # is a warning at maximal lenght of text should be displayed and the input text is at it's maximum the info is drawn
        if self.input_text_ist_max_len and self.max_len_info_anzeigen:
            t_input = self.input_max_len_font.render(f"Maximale Länge Erreicht!", True, (255, 255, 255))
            win.blit(t_input, (self.anfangs_x - t_input.get_width()//2, self.input_rect.y + self.input_rect.height + t_input.get_height()//2))


if __name__ == '__main__':
  

    import os
    import sys

    SCRWIDTH = 600
    SCRHEIGHT = 600

    HW = SCRWIDTH //2
    HH = SCRHEIGHT //2

    WHITE = (255, 255, 255)
    BLACK = (0, 0, 0)
    GREY = (100, 100, 100)
    RED = (255, 30, 30)
    GREEN = (30, 255, 30)
    BLUE = (30, 30, 255)

    FPS = 24

    pygame.init()
    WIN = pygame.display.set_mode((SCRWIDTH, SCRHEIGHT))
    pygame.display.set_caption("Space Game")
    FONT = pygame.font.SysFont("comicsans", 30)
    directory_of_file = os.path.normpath(sys.argv[0] + os.sep + os.pardir)  

    CLOCK = pygame.time.Clock()

    def draw():
        WIN.fill((0, 0, 0))


    def main():   
        run = True 
        input_box = InputBox(100, 100, 250, 50,  anfangs_anzeige_text = ["lol", "rutsch"], #####
                            umrandung= "rect", mit_zeilen_umbruch=True, input_anfangs_active= False, vergroserungs_richtung= "beide", ####
                            font_size_height_rel = 1, zeilen_abstand_rel= 0.7, binde_seite= "rechts")  #####   

        while run:
            CLOCK.tick(FPS)
            for event in pygame.event.get():   
                if event.type == pygame.QUIT:
                    run = False
                input_box.event_check(event) #####

            input_box.update() #####

            draw()
            input_box.draw(WIN) #####

            pygame.display.update()


    main()
    pygame.quit()



import eigmod.collisionen
import sys
import os
import eigmod
import pygame
import random
vec = pygame.math.Vector2


class Buttons:
    
    def __init__(self, win, scrwidth, scrheight, index, anzahl, inhalt, abstand=40,
                 width=200, height=70, gesamt_verschiebung_y=0, gesamt_verschiebung_x=0, font_name ="comicsans", font_path = None,
                 color_normal= (90, 230, 90), color_active=(0, 0, 0) , text_color=None, font_size=40, verschiebung_hintergrund=8,
                 buttons_vertical=True, with_draw_activation=True, button_aufbau_ist_mitte=True, start_x=None, start_y=None,
                 is_disabled = False, disabled_color_erhohung = 40, nur_schrift = False, nur_umrandung = False,
                 umrandungs_dicke = 0):

        standard_normal = (90, 230, 90)
        standard_active = (0, 0, 0)

        # nessesary arguments
        self.win = win
        self.scrwidth = scrwidth
        self.scrheight = scrheight
        self.index = index
        self.anzahl = anzahl  # anzahl an buttons
        self.inhalt = inhalt  # text für den button

        # optinal
        self.abstand = abstand  # abstand zwischen den buttons
        self.width = width
        self.height = height
        
        # alle buttons werden um die zahl in y richtung verschoben
        self.gesamt_verschiebung_y = gesamt_verschiebung_y
        self.gesamt_verschiebung_x = gesamt_verschiebung_x  # x richtung

        if font_path:
            self.font = pygame.font.Font(font_path, 30)     
        else:
            self.font = pygame.font.SysFont(font_name,  30)

            
        # top (haupt) farbe wenn nicht auf button drauf
        self.color_normal = color_normal
        self.color_active = color_active  # farbe wenn auf button drauf sonst drunter
        self.font_size = font_size
        # um wie viel der schatten hintergrund verschoben ist
        self.verschiebung_hintergrund = verschiebung_hintergrund
        # wenn true dann sind buttons vertikal aufgestellen, wenn false horizontal
        self.buttons_vertical = buttons_vertical
        # wenn true verandern buttons farbe wenn mousecurser drauf
        self.with_draw_activation = with_draw_activation
        # wenn true ist der aufbau in der mitte gecentert
        self.button_aufbau_ist_mitte = button_aufbau_ist_mitte
        # wenn nicht in der mitte gecentert dann ist dies start koordinate x
        self.start_x = start_x
        self.start_y = start_y  # start koordinate y

        # ob button am anfang diabled ist und wenn ja um wieviel die Farb werte gehoben werden um dies zu zeigen
        self.is_disabled = is_disabled
        self.disabled_color_erhohung = disabled_color_erhohung

        self.text_color = text_color  # frabe des gezeicheten textes

        if self.text_color and self.color_active == standard_active and self.color_normal == standard_normal:
            self.color_normal = self.color_active = self.text_color
        # wenn nicht bestimmt dann immer die bottem farbe (bei nicht aktivierung ist es active color)
        if not self.text_color:
            self.text_color = self.color_active
    
        # wenn aktiviert schrift ohne hintergrund is displayed
        self.nur_schrift = nur_schrift
        # wenn aktiviert nur rumrandung des rect als hintergrund
        self.nur_umrandung = nur_umrandung
        self.umrandungs_dicke = umrandungs_dicke
        if self.umrandungs_dicke:
            self.nur_umrandung = True
        # later
        self.text_cords = None  # koordinaten des textes

        # dynamic
        self.is_active = False  # ob mousecurser auf button
         

        self.set_botton_position()
        self.set_text_position()

    def set_botton_position(self):
        """finds out position of button and sets its cords
        """

        if self.buttons_vertical:
            if self.button_aufbau_ist_mitte:
                x = int(self.scrwidth/2 - self.width /
                        2 + self.gesamt_verschiebung_x)

                gesamt = self.anzahl * self.height + \
                    (self.anzahl - 1) * self.abstand
                abstand_oben_unten = (self.scrheight - gesamt)/2
                y = int(abstand_oben_unten + self.index *
                        (self.height + self.abstand)) + self.gesamt_verschiebung_y
            else:
                # button haben start position
                x = self.start_x
                y = int(self.start_y + self.index *
                        (self.height + self.abstand))

        else:
            if self.button_aufbau_ist_mitte:
                y = int(self.scrheight/2 - self.height /
                        2 + self.gesamt_verschiebung_y)

                gesamt = self.anzahl * self.width + \
                    (self.anzahl - 1) * self.abstand
                abstand_rechts_links = (self.scrwidth - gesamt)/2
                x = int(abstand_rechts_links + self.index *
                        (self.width + self.abstand)) - self.gesamt_verschiebung_x
            else:
                # button haben start position
                y = self.start_y
                x = int(self.start_x + self.index *
                        (self.width + self.abstand))

        self.x, self.y = x, y

    def set_text_position(self):
        """sets the position at which the text will be drawn
        """

        text = self.font.render(self.inhalt, True, (0, 0, 0))
        mitte_x = int((self.x + self.width/2) - (text.get_width()/2))
        mitte_y = int((self.y + self.height/2) - (text.get_height()/2))

        self.text_cords = vec(mitte_x, mitte_y)

    def get_if_clicked(self, mouse, mouse_event):
        """checks of mouse is on button and if mouse presses

        Args:
            mouse (tuple): mouse position got by pygame.mouse.get_pos()
            mouse_event (bool): if mousebutton you want to monitor is pressed

        Returns:
            bool: if on button clicked
        """
        hover = self.get_mouse_collision(mouse)
        
        if hover and mouse_event:
            return True
        return False

    def get_mouse_collision(self, maus, ignore_disabled = False):
        """returns if the mouse is on the button

        Args:
            maus (tuple): mouse position

        Returns:
            bool: if mouse on button
        """
        if not self.is_disabled or ignore_disabled:
            # wenn collision entweder mit dem square des buttons oder dessen schatten
            if eigmod.collisionen.point_square(maus, (self.x, self.y), (self.width, self.height))\
                    or eigmod.collisionen.point_square(maus, (self.x + self.verschiebung_hintergrund, self.y + self.verschiebung_hintergrund), (self.width, self.height)) and not self.nur_schrift:
                self.is_active = True
                return True
            else:
                self.is_active = False
                return False
        else:
            self.is_active = False
            return False

    def draw(self):
        """draws button with text and also considers the state so weather the mouse is on the button or not
        """

        top_color = self.color_normal
        bottem_color = self.color_active

        if self.is_active and self.with_draw_activation:
            top_color = self.color_active
            bottem_color = self.color_normal

        if self.text_color == top_color:
            self.text_color = bottem_color
         

        draw_text_color = self.text_color


        if self.is_disabled:
            # wenn disabled kommt helles overlay also alle farben nach oben
            
            top_color = color_erhohen(top_color, self.disabled_color_erhohung)
            bottem_color = color_erhohen(bottem_color, self.disabled_color_erhohung)
            draw_text_color = color_erhohen(draw_text_color, self.disabled_color_erhohung)
  
        if not self.nur_schrift:
            

            if self.verschiebung_hintergrund != 0:
                pygame.draw.rect(self.win, bottem_color,
                                 (self.x + self.verschiebung_hintergrund, self.y + self.verschiebung_hintergrund, self.width, self.height), self.umrandungs_dicke)
                            
            pygame.draw.rect(self.win, top_color,
                             (self.x, self.y, self.width, self.height), self.umrandungs_dicke)
            

        
        text = self.font.render(self.inhalt, True, draw_text_color)
        self.win.blit(text, (self.text_cords.x, self.text_cords.y))
    

def color_erhohen(color, delta):
    """erhoht farbwerte wenn button disabled ist 

    Args:
        color (tuple): color
        delta (int): umwieviel erhoht werden muss

    Returns:
        tuple: new color
    """
    r ,g ,b = color
    new_color = (wert_max_255(r, delta), wert_max_255(g, delta), wert_max_255(b, delta))
    return new_color
    
def wert_max_255(x, delta):
    if x + delta <= 255:
        return x + delta
    else:
        return 255
    
if __name__ == '__main__':
    SCRWIDTH = 800
    SCRHEIGHT = 600

    HW = SCRWIDTH // 2
    HH = SCRHEIGHT // 2

    WHITE = (255, 255, 255)
    BLACK = (0, 0, 0)
    GREY = (100, 100, 100)
    RED = (255, 30, 30)
    GREEN = (30, 255, 30)
    BLUE = (30, 30, 255)

    FPS = 60


    pygame.init()
    WIN = pygame.display.set_mode((SCRWIDTH, SCRHEIGHT))
    pygame.display.set_caption("Space Game")
    directory_of_file = os.path.normpath(sys.argv[0] + os.sep + os.pardir)


    CLOCK = pygame.time.Clock()


    def draw():
        WIN.fill(RED)
        for index, button in enumerate(buttons):
            active = button.draw()


    menübuttons = ["<", ">", "fd", "hallo"]

    buttons = []
    for index, menübutton in enumerate(menübuttons):
        buttons.append(Buttons(WIN, SCRWIDTH, SCRHEIGHT, index, len(
            menübuttons), menübutton, buttons_vertical=False, width=70, height=70,
            with_draw_activation= False, nur_schrift=False,
            verschiebung_hintergrund= 5  ))  

  
    # menübuttons = [["Continue"], ["Highscores"], ["Shop"],
    #                ["Credits"]]

    # buttons = []
    # for index, menübutton in enumerate(menübuttons):
    #     buttons.append(Buttons(WIN, SCRWIDTH, SCRHEIGHT, index, len(
    #         menübuttons), menübutton[0],  gesamt_verschiebung_y=-20, abstand_oben=0 , abstand_links= 0))


    def main():
        run = True

        while run:
            mouse_button_down = False
            CLOCK.tick(FPS)
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    run = False
                if event.type == pygame.MOUSEBUTTONDOWN and event.button == 1:
                    mouse_button_down = True

            keys = pygame.key.get_pressed()

            mouse = pygame.mouse.get_pos()
            for index, button in enumerate(buttons):
                active = button.get_mouse_collision(mouse)
                pressed = button.get_if_clicked(mouse, mouse_button_down)
                if pressed: 
                    button.is_disabled = not button.is_disabled

                if random.randint(0, 100) == 0:
                    button.is_disabled = False



            draw()

            pygame.display.update()


    main()
    pygame.quit()



from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.1'
DESCRIPTION = 'Modul'

# Setting up
setup(
    name="eigmod",
    version=VERSION,
    author="felix-95",
    author_email="felix.schaefer6@gmx.de",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=["pygame"],
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3"
    ]
)


import math

def square_square(cord1, dim1, cord2, dim2, speed1 = (0,0), speed2 = (0,0)):
    """checks for collision between two squares

    Args:
        cord1 (tuple): (x1, y1)
        dim1 (tuple): (width1, height1)
        cord2 (tuple): (x2, y2)
        dim2 (tuple): (width2, heigh2)
        speed1 (tuple, optional): check for col in advance. Defaults to (0,0).
        speed2 (tuple, optional): check for col in advance. Defaults to (0,0).

    Returns:
        [type]: [description]
    """
    if cord1[0] + dim1[0] + speed1[0] > cord2[0] + speed2[0]  and cord1[0] + speed1[0] < cord2[0]  + dim2[0] + speed2[0]: # x-achse Überlappung
        if cord1[1] + dim1[1] + speed1[1] > cord2[1] + speed2[1] and cord1[1] + speed1[1] < cord2[1]  + dim2[1]+ speed2[1]: # y achenn Überlappung
            return True
    return False

# print(square_square((-23, 389), (40, 40), (-1600, 0), (0, 1200)))
# print(square_square((1, 1), (1, 1), (1, 1), (2, 2)))

### UNUSED #########################
def square_wall(cord1, dim1, cord2, dim2, speed1 = (0,0)):
    return square_square(cord1, dim1, cord2, dim2, speed1)
####################################

def point_square(cord1, cord2, dim2):
    if cord1[0] > cord2[0] and cord1[0] < cord2[0]  + dim2[0]: # x-achse Überlappung
        if cord1[1] > cord2[1]  and cord1[1] < cord2[1]  + dim2[1] : # y achenn Überlappung
            return True
    return False

    
def point_line(cord1, cord2, dim2, mode):
    
    if dim2[0] == 0: # vertikale Linie 
        if cord1[1] > cord2[1] and cord1[1] < cord2[1] + dim2[1]:
            if mode == "g": # größer modus
                if cord1[0] > cord2[0]:
                    return True
            elif mode == "k": 
                if cord1[0] < cord2[0]:
                    return True
            
        return False

    elif dim2[1] == 0: # hoizontale Linie 
        if cord1[0] > cord2[0] and cord1[0] < cord2[0] + dim2[0]:
            if mode == "g": # größer modus
                if cord1[1] > cord2[1]:
                    return True
            elif mode == "k": 
                if cord1[1] < cord2[1]:
                    return True
            
        return False
            
    else: 
        raise ValueError

def circle_circle(x1,y1, r1, x2,y2,r2, uberscheindungs_fact =1):
    """checks for two colliding circles

    Args:
        x1 (numb): 
        y1 (numb): 
        r1 (numb): 
        x2 (numb): 
        y2 (numb): 
        r2 (numb): 
        uberscheiungs_fakt: das mal radius bestimmt über col, wenn 1 dann bei geringerster beruhrung true

    Returns: True/False 
    """
    
    center_dis = math.sqrt((x1- x2) ** 2 + (y1-y2)**2)
    if center_dis < (r1 + r2) * uberscheindungs_fact:
        return True
    else:
        return False

# print(circle_circle(1,1,1,2,2,1, 0.8))




